@@ -1,4 +1,5 @@
 import asyncio
+import json
 import logging
 from typing import AsyncGenerator, List, Tuple, cast
 
@@ -70,8 +71,8 @@ class WebPropertiesManager(IWebPropertiesManager):
                     try:
                         if not await _eval(client_reponse):
                             continue
-                    except (aiohttp.client_exceptions.ContentTypeError, asyncio.TimeoutError):
-                        self._logger.warning('Response content unpacking failed.')
+                    except (aiohttp.client_exceptions.ContentTypeError, asyncio.TimeoutError, json.decoder.JSONDecodeError):
+                        self._logger.warning(f'Response content unpacking failed for {heuristic.__engine__.name}.')
                         continue
 
                     yield heuristic, heuristic.__engine__
